@@ -45,8 +45,9 @@
  */
 package gen.lib.gvc;
 import static gen.lib.cgraph.attr__c.agattr;
-import static gen.lib.gvc.gvconfig__c.gvconfig;
+import static gen.lib.common.textspan__c.textfont_dict_open;
 import static gen.lib.gvc.gvcontext__c.gvNEWcontext;
+import static gen.lib.gvc.gvtextlayout__c.gvtextlayout_select;
 import static smetana.core.JUtilsDebug.ENTERING;
 import static smetana.core.JUtilsDebug.LEAVING;
 import static smetana.core.Macro.AGNODE;
@@ -167,7 +168,10 @@ try {
     agattr(null, AGNODE, new CString("label"), new CString("\\N"));
     /* default to no builtins, demand loading enabled */
     gvc = (GVC_s) gvNEWcontext(null, (NOT(0)));
-    gvconfig(gvc, false); /* configure for available plugins */
+    /* builtins don't require LTDL */
+    gvc.setInt("config_found", 0);
+    gvtextlayout_select(gvc);   /* choose best available textlayout plugin immediately */
+    textfont_dict_open(gvc);    /* initialize font dict */
     return gvc;
 } finally {
 LEAVING("f3vdhir2c7dz3pvmx9d3m4lx1","gvContext");
