@@ -68,6 +68,7 @@ public class Option {
 	private boolean pipeNoStdErr = false;
 	private boolean syntax = false;
 	private boolean checkOnly = false;
+	private OptionPreprocOutputMode preprocessorOutput = null;
 	private boolean failfast = false;
 	private boolean failfast2 = false;
 	private boolean pattern = false;
@@ -78,10 +79,12 @@ public class Option {
 	private int nbThreads = 0;
 	private int ftpPort = -1;
 	private boolean hideMetadata = false;
+	private boolean checkMetadata = false;
 	private int imageIndex = 0;
 
 	private File outputDir = null;
 	private File outputFile = null;
+	private String filename;
 
 	private final List<String> result = new ArrayList<String>();
 
@@ -106,7 +109,13 @@ public class Option {
 		}
 		for (int i = 0; i < arg.length; i++) {
 			String s = arg[i];
-			if (s.equalsIgnoreCase("-tsvg") || s.equalsIgnoreCase("-svg")) {
+			if (s.equalsIgnoreCase("-headless")) {
+				// Useless because done in Run.java
+				if (i != 0) {
+					Log.error("Warning: -headless flag must be the first one in the command line");
+				}
+				System.setProperty("java.awt.headless", "true");
+			} else if (s.equalsIgnoreCase("-tsvg") || s.equalsIgnoreCase("-svg")) {
 				setFileFormatOption(new FileFormatOption(FileFormat.SVG));
 			} else if (s.equalsIgnoreCase("-tsvg:nornd") || s.equalsIgnoreCase("-svg:nornd")) {
 				setFileFormatOption(new FileFormatOption(FileFormat.SVG));
@@ -168,6 +177,12 @@ public class Option {
 					continue;
 				}
 				charset = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg[i]);
+			} else if (s.equalsIgnoreCase("-filename")) {
+				i++;
+				if (i == arg.length) {
+					continue;
+				}
+				filename = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg[i]);
 			} else if (s.startsWith("-o") && s.length() > 3) {
 				s = s.substring(2);
 				outputDir = new File(StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(s));
@@ -282,8 +297,8 @@ public class Option {
 				OptionFlags.getInstance().setGui(true);
 			} else if (s.equalsIgnoreCase("-encodesprite")) {
 				OptionFlags.getInstance().setEncodesprite(true);
-			} else if (s.equalsIgnoreCase("-nosuggestengine")) {
-				OptionFlags.getInstance().setUseSuggestEngine(false);
+				// } else if (s.equalsIgnoreCase("-nosuggestengine")) {
+				// OptionFlags.getInstance().setUseSuggestEngine(false);
 			} else if (s.equalsIgnoreCase("-printfonts")) {
 				OptionFlags.getInstance().setPrintFonts(true);
 			} else if (s.equalsIgnoreCase("-dumphtmlstats")) {
@@ -296,6 +311,14 @@ public class Option {
 				OptionFlags.getInstance().setEnableStats(true);
 			} else if (s.equalsIgnoreCase("-disablestats")) {
 				OptionFlags.getInstance().setEnableStats(false);
+			} else if (s.equalsIgnoreCase("-extractstdlib")) {
+				OptionFlags.getInstance().setExtractStdLib(true);
+			} else if (s.equalsIgnoreCase("-stdlib")) {
+				OptionFlags.getInstance().setStdLib(true);
+			} else if (s.equalsIgnoreCase("-clipboard")) {
+				OptionFlags.getInstance().setClipboard(true);
+			} else if (s.equalsIgnoreCase("-clipboardloop")) {
+				OptionFlags.getInstance().setClipboardLoop(true);
 			} else if (s.equalsIgnoreCase("-htmlstats")) {
 				StatsUtils.setHtmlStats(true);
 			} else if (s.equalsIgnoreCase("-xmlstats")) {
@@ -310,6 +333,12 @@ public class Option {
 				textProgressBar = true;
 			} else if (s.equalsIgnoreCase("-nometadata")) {
 				hideMetadata = true;
+			} else if (s.equalsIgnoreCase("-preproc")) {
+				preprocessorOutput = OptionPreprocOutputMode.NORMAL;
+			} else if (s.equalsIgnoreCase("-cypher")) {
+				preprocessorOutput = OptionPreprocOutputMode.CYPHER;
+			} else if (s.equalsIgnoreCase("-checkmetadata")) {
+				checkMetadata = true;
 			} else if (s.equalsIgnoreCase("-pipeimageindex")) {
 				i++;
 				if (i == arg.length) {
@@ -397,7 +426,7 @@ public class Option {
 	}
 
 	public final static String getPattern() {
-		return "(?i)^.*\\.(txt|tex|java|htm|html|c|h|cpp|apt|pu)$";
+		return "(?i)^.*\\.(txt|tex|java|htm|html|c|h|cpp|apt|pu|pump|hpp|hh)$";
 	}
 
 	public void setOutputDir(File f) {
@@ -412,7 +441,15 @@ public class Option {
 		final Defines result = Defines.createWithFileName(f);
 		for (Map.Entry<String, String> ent : defines.entrySet()) {
 			result.define(ent.getKey(), Arrays.asList(ent.getValue()), false);
+		}
+		return result;
+	}
 
+	public Defines getDefaultDefines() {
+		final Defines result = Defines.createEmpty();
+		result.overrideFilename(filename);
+		for (Map.Entry<String, String> ent : defines.entrySet()) {
+			result.define(ent.getKey(), Arrays.asList(ent.getValue()), false);
 		}
 		return result;
 	}
@@ -548,4 +585,20 @@ public class Option {
 		return imageIndex;
 	}
 
+	public final void setFilename(String filename) {
+		this.filename = filename;
+	}
+
+	public final boolean isCheckMetadata() {
+		return checkMetadata;
+	}
+
+	public final OptionPreprocOutputMode getPreprocessorOutputMode() {
+		return preprocessorOutput;
+	}
+
+	// public final void setPreprocessorOutput(boolean preprocessorOutput) {
+	// this.preprocessorOutput = preprocessorOutput;
+	// }
+
 }
