@@ -36,10 +36,12 @@
 package net.sourceforge.plantuml;
 
 import java.awt.Font;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
@@ -48,6 +50,7 @@ import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.command.regex.MyPattern;
 import net.sourceforge.plantuml.command.regex.Pattern2;
 import net.sourceforge.plantuml.creole.CommandCreoleMonospaced;
+import net.sourceforge.plantuml.cucadiagram.LinkStyle;
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.DotSplines;
@@ -91,7 +94,9 @@ public class SkinParam implements ISkinParam {
 	}
 
 	public void setParam(String key, String value) {
-		params.put(cleanForKey(key), StringUtils.trin(value));
+		for (String key2 : cleanForKey(key)) {
+			params.put(key2, StringUtils.trin(value));
+		}
 	}
 
 	private SkinParam(UmlDiagramType type) {
@@ -108,16 +113,23 @@ public class SkinParam implements ISkinParam {
 		return result;
 	}
 
-	static String cleanForKey(String key) {
+	private final Map<String, List<String>> cacheCleanForKey = new HashMap<String, List<String>>();
+
+	List<String> cleanForKey(String key) {
+		List<String> result = cacheCleanForKey.get(key);
+		if (result == null) {
+			result = cleanForKeySlow(key);
+			cacheCleanForKey.put(key, result);
+		}
+		return result;
+	}
+
+	List<String> cleanForKeySlow(String key) {
 		key = StringUtils.trin(StringUtils.goLowerCase(key));
 		key = key.replaceAll("_|\\.|\\s", "");
 		// key = replaceSmart(key, "partition", "package");
 		key = replaceSmart(key, "sequenceparticipant", "participant");
 		key = replaceSmart(key, "sequenceactor", "actor");
-		// if (key.contains("arrow")) {
-		// key = key.replaceAll("activityarrow|objectarrow|classarrow|componentarrow|statearrow|usecasearrow",
-		// "genericarrow");
-		// }
 		key = key.replaceAll("activityarrow", "arrow");
 		key = key.replaceAll("objectarrow", "arrow");
 		key = key.replaceAll("classarrow", "arrow");
@@ -125,13 +137,17 @@ public class SkinParam implements ISkinParam {
 		key = key.replaceAll("statearrow", "arrow");
 		key = key.replaceAll("usecasearrow", "arrow");
 		key = key.replaceAll("sequencearrow", "arrow");
-		final Matcher2 m = stereoPattern.matcher(key);
-		if (m.find()) {
-			final String s = m.group(1);
-			key = key.replaceAll(stereoPatternString, "");
-			key += "<<" + s + ">>";
+		key = key.replaceAll("align$", "alignment");
+		final Matcher2 mm = stereoPattern.matcher(key);
+		final List<String> result = new ArrayList<String>();
+		while (mm.find()) {
+			final String s = mm.group(1);
+			result.add(key.replaceAll(stereoPatternString, "") + "<<" + s + ">>");
 		}
-		return key;
+		if (result.size() == 0) {
+			result.add(key);
+		}
+		return Collections.unmodifiableList(result);
 	}
 
 	private static String replaceSmart(String s, String src, String target) {
@@ -158,7 +174,13 @@ public class SkinParam implements ISkinParam {
 	}
 
 	public String getValue(String key) {
-		return params.get(cleanForKey(key));
+		for (String key2 : cleanForKey(key)) {
+			final String result = params.get(key2);
+			if (result != null) {
+				return result;
+			}
+		}
+		return null;
 	}
 
 	static String humanName(String key) {
@@ -191,10 +213,21 @@ public class SkinParam implements ISkinParam {
 			return null;
 		}
 		final boolean acceptTransparent = param == ColorParam.background
-				|| param == ColorParam.sequenceGroupBodyBackground;
+				|| param == ColorParam.sequenceGroupBodyBackground || param == ColorParam.sequenceBoxBackground;
 		return getIHtmlColorSet().getColorIfValid(value, acceptTransparent);
 	}
 
+	public char getCircledCharacter(Stereotype stereotype) {
+		if (stereotype == null) {
+			throw new IllegalArgumentException();
+		}
+		final String value2 = getValue("spotchar" + stereotype.getLabel(false));
+		if (value2 != null && value2.length() > 0) {
+			return value2.charAt(0);
+		}
+		return 0;
+	}
+
 	public Colors getColors(ColorParam param, Stereotype stereotype) {
 		if (stereotype != null) {
 			checkStereotype(stereotype);
@@ -388,6 +421,17 @@ public class SkinParam implements ISkinParam {
 		result.add("TabSize");
 		result.add("MaxAsciiMessageLength");
 		result.add("ColorArrowSeparationSpace");
+		result.add("ResponseMessageBelowArrow");
+		result.add("GenericDisplay");
+		result.add("PathHoverColor");
+		result.add("SwimlaneWidth");
+		result.add("PageBorderColor");
+		result.add("PageExternalColor");
+		result.add("PageMargin");
+		result.add("WrapWidth");
+		result.add("SwimlaneWidth");
+		result.add("SwimlaneWrapTitleWidth");
+
 		for (FontParam p : EnumSet.allOf(FontParam.class)) {
 			final String h = humanName(p.name());
 			result.add(h + "FontStyle");
@@ -403,6 +447,10 @@ public class SkinParam implements ISkinParam {
 			final String h = capitalize(p.name());
 			result.add(h + "Thickness");
 		}
+		for (AlignmentParam p : EnumSet.allOf(AlignmentParam.class)) {
+			final String h = capitalize(p.name());
+			result.add(h);
+		}
 		return Collections.unmodifiableSet(result);
 	}
 
@@ -429,14 +477,14 @@ public class SkinParam implements ISkinParam {
 		return DotSplines.SPLINES;
 	}
 
-	public HorizontalAlignment getHorizontalAlignment(AlignParam param, ArrowDirection arrowDirection) {
+	public HorizontalAlignment getHorizontalAlignment(AlignmentParam param, ArrowDirection arrowDirection) {
 		final String value;
 		switch (param) {
-		case SEQUENCE_MESSAGE_ALIGN:
-			value = getArg(getValue(AlignParam.SEQUENCE_MESSAGE_ALIGN.name()), 0);
+		case sequenceMessageAlignment:
+			value = getArg(getValue(AlignmentParam.sequenceMessageAlignment.name()), 0);
 			break;
-		case SEQUENCE_MESSAGETEXT_ALIGN:
-			value = getArg(getValue(AlignParam.SEQUENCE_MESSAGE_ALIGN.name()), 1);
+		case sequenceMessageTextAlignment:
+			value = getArg(getValue(AlignmentParam.sequenceMessageAlignment.name()), 1);
 			break;
 		default:
 			value = getValue(param.name());
@@ -448,6 +496,9 @@ public class SkinParam implements ISkinParam {
 			if (arrowDirection == ArrowDirection.RIGHT_TO_LEFT_REVERSE) {
 				return HorizontalAlignment.RIGHT;
 			}
+			if (arrowDirection == ArrowDirection.BOTH_DIRECTION) {
+				return HorizontalAlignment.CENTER;
+			}
 		}
 		if ("reversedirection".equalsIgnoreCase(value)) {
 			if (arrowDirection == ArrowDirection.LEFT_TO_RIGHT_NORMAL) {
@@ -456,9 +507,14 @@ public class SkinParam implements ISkinParam {
 			if (arrowDirection == ArrowDirection.RIGHT_TO_LEFT_REVERSE) {
 				return HorizontalAlignment.LEFT;
 			}
+			if (arrowDirection == ArrowDirection.BOTH_DIRECTION) {
+				return HorizontalAlignment.CENTER;
+			}
 		}
 		final HorizontalAlignment result = HorizontalAlignment.fromString(value);
-		if (result == null) {
+		if (result == null && param == AlignmentParam.noteTextAlignment) {
+			return getDefaultTextAlignment(HorizontalAlignment.LEFT);
+		} else if (result == null) {
 			return param.getDefaultValue();
 		}
 		return result;
@@ -621,8 +677,39 @@ public class SkinParam implements ISkinParam {
 		return 0;
 	}
 
-	public double getRoundCorner(String param, Stereotype stereotype) {
-		String key = param + "roundcorner";
+	public double getDiagonalCorner(CornerParam param, Stereotype stereotype) {
+		final String key = param.getDiagonalKey();
+		Double result = getCornerInternal(key, param, stereotype);
+		if (result != null) {
+			return result;
+		}
+		result = getCornerInternal(key, param, null);
+		if (result != null) {
+			return result;
+		}
+		if (param == CornerParam.DEFAULT) {
+			return 0;
+		}
+		return getDiagonalCorner(CornerParam.DEFAULT, stereotype);
+	}
+
+	public double getRoundCorner(CornerParam param, Stereotype stereotype) {
+		final String key = param.getRoundKey();
+		Double result = getCornerInternal(key, param, stereotype);
+		if (result != null) {
+			return result;
+		}
+		result = getCornerInternal(key, param, null);
+		if (result != null) {
+			return result;
+		}
+		if (param == CornerParam.DEFAULT) {
+			return 0;
+		}
+		return getRoundCorner(CornerParam.DEFAULT, stereotype);
+	}
+
+	private Double getCornerInternal(String key, CornerParam param, Stereotype stereotype) {
 		if (stereotype != null) {
 			key += stereotype.getLabel(false);
 		}
@@ -630,26 +717,62 @@ public class SkinParam implements ISkinParam {
 		if (value != null && value.matches("\\d+")) {
 			return Double.parseDouble(value);
 		}
-		return 0;
+		return null;
 	}
 
 	public UStroke getThickness(LineParam param, Stereotype stereotype) {
+		LinkStyle style = null;
 		if (stereotype != null) {
 			checkStereotype(stereotype);
+
+			final String styleValue = getValue(param.name() + "style" + stereotype.getLabel(false));
+			if (styleValue != null) {
+				style = LinkStyle.fromString2(styleValue);
+			}
+
 			final String value2 = getValue(param.name() + "thickness" + stereotype.getLabel(false));
 			if (value2 != null && value2.matches("[\\d.]+")) {
-				return new UStroke(Double.parseDouble(value2));
+				if (style == null) {
+					style = LinkStyle.NORMAL();
+				}
+				return style.goThickness(Double.parseDouble(value2)).getStroke3();
 			}
 		}
 		final String value = getValue(param.name() + "thickness");
 		if (value != null && value.matches("[\\d.]+")) {
-			return new UStroke(Double.parseDouble(value));
+			if (style == null) {
+				style = LinkStyle.NORMAL();
+			}
+			return style.goThickness(Double.parseDouble(value)).getStroke3();
+		}
+		if (style == null) {
+			final String styleValue = getValue(param.name() + "style");
+			if (styleValue != null) {
+				style = LinkStyle.fromString2(styleValue);
+			}
+		}
+		if (style != null && style.isNormal() == false) {
+			return style.getStroke3();
 		}
 		return null;
 	}
 
 	public LineBreakStrategy maxMessageSize() {
-		return new LineBreakStrategy(getValue("maxmessagesize"));
+		String value = getValue("wrapmessagewidth");
+		if (value == null) {
+			value = getValue("maxmessagesize");
+		}
+		return new LineBreakStrategy(value);
+	}
+
+	public LineBreakStrategy wrapWidth() {
+		final String value = getValue("wrapwidth");
+		return new LineBreakStrategy(value);
+	}
+
+	public LineBreakStrategy swimlaneWrapTitleWidth() {
+		final String value = getValue("swimlanewraptitlewidth");
+		return new LineBreakStrategy(value);
 	}
 
 	public boolean strictUmlStyle() {
@@ -814,7 +937,7 @@ public class SkinParam implements ISkinParam {
 	public int swimlaneWidth() {
 		final String value = getValue("swimlanewidth");
 		if ("same".equalsIgnoreCase(value)) {
-			return -1;
+			return SWIMLANE_WIDTH_SAME;
 		}
 		if (value != null && value.matches("\\d+")) {
 			return Integer.parseInt(value);
@@ -854,4 +977,33 @@ public class SkinParam implements ISkinParam {
 		return false;
 	}
 
+	public boolean displayGenericWithOldFashion() {
+		final String value = getValue("genericDisplay");
+		if ("old".equalsIgnoreCase(value)) {
+			return true;
+		}
+		return false;
+	}
+
+	public boolean responseMessageBelowArrow() {
+		final String value = getValue("responsemessagebelowarrow");
+		if ("true".equalsIgnoreCase(value)) {
+			return true;
+		}
+		return false;
+	}
+
+	public TikzFontDistortion getTikzFontDistortion() {
+		final String value = getValue("tikzFont");
+		return TikzFontDistortion.fromValue(value);
+	}
+
+	public boolean svgDimensionStyle() {
+		final String value = getValue("svgdimensionstyle");
+		if ("false".equalsIgnoreCase(value)) {
+			return false;
+		}
+		return true;
+	}
+
 }
