@@ -38,6 +38,7 @@ package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 import java.awt.geom.Dimension2D;
 import java.util.Set;
 
+import net.sourceforge.plantuml.AlignmentParam;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineParam;
@@ -82,7 +83,7 @@ public class FtileGroup extends AbstractFtile {
 		super(inner.skinParam());
 		this.backColor = backColor == null ? HtmlColorUtils.WHITE : backColor;
 		this.inner = FtileUtils.addHorizontalMargin(inner, 10);
-		this.borderColor = backColor == null ? HtmlColorUtils.BLACK : borderColor;
+		this.borderColor = borderColor == null ? HtmlColorUtils.BLACK : borderColor;
 		final UFont font = skinParam.getFont(null, false, FontParam.PARTITION);
 
 		final HtmlColor fontColor = skinParam.getFontHtmlColor(null, FontParam.PARTITION);
@@ -130,12 +131,12 @@ public class FtileGroup extends AbstractFtile {
 		return new UTranslate(suppWidth / 2, diffHeightTitle(stringBounder) + headerNoteHeight(stringBounder));
 	}
 
-	private static MinMax getMinMax(TextBlock tb, StringBounder stringBounder) {
+	private MinMax getInnerMinMax(StringBounder stringBounder) {
 		final LimitFinder limitFinder = new LimitFinder(stringBounder, false);
 		final UGraphicForSnake interceptor = new UGraphicForSnake(limitFinder);
 		final UGraphicInterceptorUDrawable interceptor2 = new UGraphicInterceptorUDrawable(interceptor);
 
-		tb.drawU(interceptor2);
+		inner.drawU(interceptor2);
 		interceptor2.flushUg();
 		return limitFinder.getMinMax();
 	}
@@ -149,9 +150,19 @@ public class FtileGroup extends AbstractFtile {
 		return suppWidth;
 	}
 
+	private FtileGeometry cachedInnerDimension;
+
 	private FtileGeometry getInnerDimension(StringBounder stringBounder) {
+		if (cachedInnerDimension == null) {
+			cachedInnerDimension = getInnerDimensionSlow(stringBounder);
+		}
+		return cachedInnerDimension;
+
+	}
+
+	private FtileGeometry getInnerDimensionSlow(StringBounder stringBounder) {
 		final FtileGeometry orig = inner.calculateDimension(stringBounder);
-		final MinMax minMax = getMinMax(inner, stringBounder);
+		final MinMax minMax = getInnerMinMax(stringBounder);
 		final double missingWidth = minMax.getMaxX() - orig.getWidth();
 		if (missingWidth > 0) {
 			return orig.addDim(missingWidth + 5, 0);
@@ -159,7 +170,8 @@ public class FtileGroup extends AbstractFtile {
 		return orig;
 	}
 
-	public FtileGeometry calculateDimension(StringBounder stringBounder) {
+	@Override
+	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		final FtileGeometry orig = getInnerDimension(stringBounder);
 		final double suppWidth = suppWidth(stringBounder);
 		final double width = orig.getWidth() + suppWidth;
@@ -184,8 +196,8 @@ public class FtileGroup extends AbstractFtile {
 
 		final SymbolContext symbolContext = new SymbolContext(backColor, borderColor).withShadow(
 				skinParam().shadowing()).withStroke(stroke);
-		USymbol.FRAME.asBig(name, TextBlockUtils.empty(0, 0), dimTotal.getWidth(), dimTotal.getHeight(), symbolContext)
-				.drawU(ug);
+		USymbol.FRAME.asBig(name, inner.skinParam().getHorizontalAlignment(AlignmentParam.packageTitleAlignment, null),
+				TextBlockUtils.empty(0, 0), dimTotal.getWidth(), dimTotal.getHeight(), symbolContext).drawU(ug);
 
 		final Dimension2D dimHeaderNote = headerNote.calculateDimension(stringBounder);
 		headerNote.drawU(ug.apply(new UTranslate(dimTotal.getWidth() - dimHeaderNote.getWidth() - 10,
