@@ -38,6 +38,8 @@ package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 import java.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -81,6 +83,14 @@ class FtileWhile extends AbstractFtile {
 	private final Ftile diamond1;
 	private final Ftile specialOut;
 
+	@Override
+	public Collection<Ftile> getMyChildren() {
+		if (specialOut == null) {
+			return Arrays.asList(whileBlock, diamond1);
+		}
+		return Arrays.asList(whileBlock, diamond1, specialOut);
+	}
+
 	public Set<Swimlane> getSwimlanes() {
 		final Set<Swimlane> result = new HashSet<Swimlane>(whileBlock.getSwimlanes());
 		result.add(getSwimlaneIn());
@@ -240,7 +250,6 @@ class FtileWhile extends AbstractFtile {
 			final double x1 = p1.getX();
 			final double y1 = p1.getY();
 			final double x2 = p2.getX() + dimDiamond1.getWidth();
-			// final double y2 = p2.getY() + dimDiamond1.getOutY() / 2;
 			final double half = (dimDiamond1.getOutY() - dimDiamond1.getInY()) / 2;
 			final double y2 = p2.getY() + dimDiamond1.getInY() + half;
 
@@ -258,8 +267,6 @@ class FtileWhile extends AbstractFtile {
 
 			ug.apply(new UTranslate(x1, y1bis)).draw(new UEmpty(5, Diamond.diamondHalfSize));
 
-			// ug = ug.apply(new UChangeColor(endInlinkColor)).apply(new UChangeBackColor(endInlinkColor));
-			// ug.apply(new UTranslate(xx, (y1 + y2) / 2)).draw(Arrows.asToUp());
 		}
 
 		public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
@@ -271,12 +278,13 @@ class FtileWhile extends AbstractFtile {
 			final Point2D p1 = translate1.getTranslated(ap1);
 			final Point2D p2 = translate2.getTranslated(ap2);
 
-			final Dimension2D dimDiamond1 = diamond1.calculateDimension(stringBounder);
+			final FtileGeometry dimDiamond1 = diamond1.calculateDimension(stringBounder);
 
 			final double x1 = p1.getX();
 			final double y1 = p1.getY();
 			final double x2 = p2.getX() + dimDiamond1.getWidth();
-			final double y2 = p2.getY() + dimDiamond1.getHeight() / 2;
+			final double half = (dimDiamond1.getOutY() - dimDiamond1.getInY()) / 2;
+			final double y2 = p2.getY() + dimDiamond1.getInY() + half;
 
 			snake.addPoint(x1, y1);
 			snake.addPoint(x1, y1 + Diamond.diamondHalfSize);
@@ -392,8 +400,6 @@ class FtileWhile extends AbstractFtile {
 			snake.goUnmergeable(MergeStrategy.LIMITED);
 
 			ug.draw(snake);
-			// ug = ug.apply(new UChangeColor(afterEndwhileColor)).apply(new UChangeBackColor(afterEndwhileColor));
-			// ug.apply(new UTranslate(Diamond.diamondHalfSize, (y1 + y2) / 2)).draw(Arrows.asToDown());
 
 			final Snake snake2 = new Snake(arrowHorizontalAlignment(), afterEndwhileColor);
 			snake2.addPoint(Diamond.diamondHalfSize, y2);
@@ -454,7 +460,8 @@ class FtileWhile extends AbstractFtile {
 		}
 	}
 
-	public FtileGeometry calculateDimension(StringBounder stringBounder) {
+	@Override
+	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		final FtileGeometry geoDiamond1 = diamond1.calculateDimension(stringBounder);
 		FtileGeometry geoWhile = whileBlock.calculateDimension(stringBounder);
 		final double diff = -geoWhile.getWidth();
