@@ -82,7 +82,7 @@ public class FtileBox extends AbstractFtile {
 	private final LinkRendering inRenreding;
 	private final Swimlane swimlane;
 	private final BoxStyle style;
-	private final ISkinParam skinParam;
+	// private final ISkinParam skinParam;
 
 	final public LinkRendering getInLinkRendering() {
 		return inRenreding;
@@ -119,13 +119,13 @@ public class FtileBox extends AbstractFtile {
 	public FtileBox(ISkinParam skinParam, Display label, UFont font, Swimlane swimlane, BoxStyle style) {
 		super(skinParam);
 		this.style = style;
-		this.skinParam = skinParam;
+		// this.skinParam = skinParam;
 		this.swimlane = swimlane;
 		this.inRenreding = new LinkRendering(HtmlColorAndStyle.build(skinParam));
 		final FontConfiguration fc = new FontConfiguration(skinParam, FontParam.ACTIVITY, null);
 		final Sheet sheet = new CreoleParser(fc, skinParam.getDefaultTextAlignment(HorizontalAlignment.LEFT),
 				skinParam, CreoleMode.FULL).createSheet(label);
-		this.tb = new SheetBlock2(new SheetBlock1(sheet, LineBreakStrategy.NONE, skinParam.getPadding()), new MyStencil(), new UStroke(1));
+		this.tb = new SheetBlock2(new SheetBlock1(sheet, skinParam.wrapWidth(), skinParam.getPadding()), new MyStencil(), new UStroke(1));
 		this.print = label.toString();
 	}
 
@@ -142,8 +142,8 @@ public class FtileBox extends AbstractFtile {
 		final double heightTotal = dimTotal.getHeight();
 		final UDrawable rect = style.getUDrawable(widthTotal, heightTotal, skinParam().shadowing());
 
-		final HtmlColor borderColor = SkinParamUtils.getColor(skinParam, ColorParam.activityBorder, null);
-		final HtmlColor backColor = SkinParamUtils.getColor(skinParam, ColorParam.activityBackground, null);
+		final HtmlColor borderColor = SkinParamUtils.getColor(skinParam(), ColorParam.activityBorder, null);
+		final HtmlColor backColor = SkinParamUtils.getColor(skinParam(), ColorParam.activityBackground, null);
 
 		ug = ug.apply(new UChangeColor(borderColor)).apply(new UChangeBackColor(backColor)).apply(getThickness());
 		rect.drawU(ug);
@@ -151,7 +151,8 @@ public class FtileBox extends AbstractFtile {
 		tb.drawU(ug.apply(new UTranslate(MARGIN, MARGIN)));
 	}
 
-	public FtileGeometry calculateDimension(StringBounder stringBounder) {
+	@Override
+	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		final Dimension2D dim = tb.calculateDimension(stringBounder);
 		return new FtileGeometry(Dimension2DDouble.delta(dim, 2 * MARGIN, 2 * MARGIN), dim.getWidth() / 2 + MARGIN, 0,
 				dim.getHeight() + 2 * MARGIN);
