@@ -150,7 +150,8 @@ public class FtileDiamondInside2 extends AbstractFtile {
 		return new FtileGeometry(dim, dim.getWidth() / 2, 0, dim.getHeight());
 	}
 
-	public FtileGeometry calculateDimension(StringBounder stringBounder) {
+	@Override
+	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		final Dimension2D diamond = calculateDimensionAlone(stringBounder);
 		final Dimension2D north = this.north.calculateDimension(stringBounder);
 		final double height = diamond.getHeight() + north.getHeight();
