@@ -55,7 +55,7 @@ import net.sourceforge.plantuml.svek.Bibliotekon;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.utils.UniqueSequence;
 
-public class Link implements Hideable, Removeable {
+public class Link extends WithLinkType implements Hideable, Removeable {
 
 	final private IEntity cl1;
 	final private IEntity cl2;
@@ -63,7 +63,6 @@ public class Link implements Hideable, Removeable {
 	private String port1;
 	private String port2;
 
-	private LinkType type;
 	final private Display label;
 
 	private int length;
@@ -82,7 +81,6 @@ public class Link implements Hideable, Removeable {
 	private final String labeldistance;
 	private final String labelangle;
 
-	private HtmlColor specificColor;
 	private boolean constraint = true;
 	private boolean inverted = false;
 	private LinkArrow linkArrow = LinkArrow.NONE;
@@ -119,9 +117,9 @@ public class Link implements Hideable, Removeable {
 		this.type = type;
 		if (Display.isNull(label)) {
 			this.label = Display.NULL;
-//		} else if (doWeHaveToRemoveUrlAtStart(label)) {
-//			this.url = label.initUrl();
-//			this.label = label.removeHeadingUrl(url).manageGuillemet();
+			// } else if (doWeHaveToRemoveUrlAtStart(label)) {
+			// this.url = label.initUrl();
+			// this.label = label.removeHeadingUrl(url).manageGuillemet();
 		} else {
 			this.label = label.manageGuillemet();
 		}
@@ -130,7 +128,7 @@ public class Link implements Hideable, Removeable {
 		this.qualifier2 = qualifier2;
 		this.labeldistance = labeldistance;
 		this.labelangle = labelangle;
-		this.specificColor = specificColor;
+		this.setSpecificColor(specificColor);
 		if (qualifier1 != null) {
 			((ILeaf) cl1).setNearDecoration(true);
 		}
@@ -142,16 +140,16 @@ public class Link implements Hideable, Removeable {
 		// }
 	}
 
-//	private static boolean doWeHaveToRemoveUrlAtStart(Display label) {
-//		if (label.size() == 0) {
-//			return false;
-//		}
-//		final String s = label.get(0).toString();
-//		if (s.matches("^\\[\\[\\S+\\]\\].+$")) {
-//			return true;
-//		}
-//		return false;
-//	}
+	// private static boolean doWeHaveToRemoveUrlAtStart(Display label) {
+	// if (label.size() == 0) {
+	// return false;
+	// }
+	// final String s = label.get(0).toString();
+	// if (s.matches("^\\[\\[\\S+\\]\\].+$")) {
+	// return true;
+	// }
+	// return false;
+	// }
 
 	public Link getInv() {
 		// if (getLength() == 1) {
@@ -159,35 +157,19 @@ public class Link implements Hideable, Removeable {
 		// cl2.setXposition(x-1);
 		// }
 		final Link result = new Link(cl2, cl1, getType().getInversed(), label, length, qualifier2, qualifier1,
-				labeldistance, labelangle, specificColor);
-		result.inverted = true;
+				labeldistance, labelangle, getSpecificColor());
+		result.inverted = !this.inverted;
 		result.port1 = this.port2;
 		result.port2 = this.port1;
+		result.url = this.url;
 		return result;
 	}
 
-	public void goDashed() {
-		type = type.getDashed();
-	}
-
-	public void goDotted() {
-		type = type.getDotted();
-	}
-
-	private boolean hidden = false;
-
-	public void goHidden() {
-		this.hidden = true;
-	}
-
+	@Override
 	public void goNorank() {
 		setConstraint(false);
 	}
 
-	public void goBold() {
-		type = type.getBold();
-	}
-
 	public String getLabeldistance() {
 		// Default in dot 1.0
 		return labeldistance;
@@ -244,6 +226,7 @@ public class Link implements Hideable, Removeable {
 		return new EntityPort(bibliotekon.getShapeUid((ILeaf) cl2), port2);
 	}
 
+	@Override
 	public LinkType getType() {
 		if (opale) {
 			return new LinkType(LinkDecor.NONE, LinkDecor.NONE);
@@ -420,14 +403,6 @@ public class Link implements Hideable, Removeable {
 		return 0;
 	}
 
-	public HtmlColor getSpecificColor() {
-		return specificColor;
-	}
-
-	public void setSpecificColor(String s) {
-		this.specificColor = HtmlColorSet.getInstance().getColorIfValid(s);
-	}
-
 	public final boolean isConstraint() {
 		return constraint;
 	}
@@ -536,16 +511,6 @@ public class Link implements Hideable, Removeable {
 		this.sametail = sametail;
 	}
 
-	private Colors colors;
-
-	public void setColors(Colors colors) {
-		this.colors = colors;
-	}
-
-	public final Colors getColors() {
-		return colors;
-	}
-
 	public void setPortMembers(String port1, String port2) {
 		this.port1 = port1;
 		this.port2 = port2;
