@@ -166,7 +166,8 @@ public class MethodsOrFieldsArea extends AbstractTextBlock implements TextBlockW
 		if (m.isStatic()) {
 			config = config.underline();
 		}
-		TextBlock bloc = Display.getWithNewlines(s).create(config, align, skinParam, CreoleMode.SIMPLE_LINE);
+		TextBlock bloc = Display.getWithNewlines(s).create(config, align, skinParam, CreoleMode.SIMPLE_LINE,
+				skinParam.wrapWidth());
 		bloc = TextBlockUtils.fullInnerPosition(bloc, m.getDisplay(false));
 		return new TextBlockTracer(m, bloc);
 	}
