@@ -37,7 +37,6 @@ package net.sourceforge.plantuml.descdiagram.command;
 import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.classdiagram.command.CommandLinkClass;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
 import net.sourceforge.plantuml.command.regex.Matcher2;
@@ -52,6 +51,7 @@ import net.sourceforge.plantuml.cucadiagram.IEntity;
 import net.sourceforge.plantuml.cucadiagram.ILeaf;
 import net.sourceforge.plantuml.cucadiagram.LeafType;
 import net.sourceforge.plantuml.cucadiagram.Link;
+import net.sourceforge.plantuml.cucadiagram.LinkArrow;
 import net.sourceforge.plantuml.cucadiagram.LinkDecor;
 import net.sourceforge.plantuml.cucadiagram.LinkType;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
@@ -59,29 +59,30 @@ import net.sourceforge.plantuml.descdiagram.DescriptionDiagram;
 import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.graphic.color.ColorParser;
 import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
 
 public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 
+	static private final String KEY1 = "dotted|dashed|plain|bold|hidden|norank|thickness=\\d+";
+	static private final String KEY2 = ",dotted|,dashed|,plain|,bold|,hidden|,norank|,thickness=\\d+";
+	static public final String LINE_STYLE = "(?:#\\w+|" + CommandLinkElement.KEY1 + ")(?:,#\\w+|"
+			+ CommandLinkElement.KEY2 + ")*";
+
 	public CommandLinkElement() {
 		super(getRegexConcat());
 	}
 
 	static RegexConcat getRegexConcat() {
-		return new RegexConcat(
-				new RegexLeaf("^"), //
+		return new RegexConcat(new RegexLeaf("^"), //
 				getGroup("ENT1"), //
 				new RegexLeaf("[%s]*"), //
 				new RegexLeaf("LABEL1", "(?:[%g]([^%g]+)[%g])?"), //
 				new RegexLeaf("[%s]*"), //
 				new RegexLeaf("HEAD2", "(0\\)|<<|[<^*+#0)]|<\\||[%s]+o)?"), //
 				new RegexLeaf("BODY1", "([-=.~]+)"), //
-				new RegexLeaf("ARROW_STYLE1",
-						"(?:\\[((?:#\\w+|dotted|dashed|plain|bold|hidden|norank)(?:,#\\w+|,dotted|,dashed|,plain|,bold|,hidden|,norank)*)\\])?"),
+				new RegexLeaf("ARROW_STYLE1", "(?:\\[(" + CommandLinkElement.LINE_STYLE + ")\\])?"), //
 				new RegexLeaf("DIRECTION", "(?:(left|right|up|down|le?|ri?|up?|do?)(?=[-=.~0()]))?"), //
 				new RegexLeaf("INSIDE", "(?:(0|\\(0\\)|\\(0|0\\))(?=[-=.~]))?"), //
-				new RegexLeaf("ARROW_STYLE2",
-						"(?:\\[((?:#\\w+|dotted|dashed|plain|bold|hidden|norank)(?:,#\\w+|,dotted|,dashed|,plain|,bold|,hidden|,norank)*)\\])?"),
+				new RegexLeaf("ARROW_STYLE2", "(?:\\[(" + CommandLinkElement.LINE_STYLE + ")\\])?"), //
 				new RegexLeaf("BODY2", "([-=.~]*)"), //
 				new RegexLeaf("HEAD1", "(\\(0|>>|[>^*+#0(]|\\|>|o[%s]+)?"), //
 				new RegexLeaf("[%s]*"), //
@@ -157,11 +158,11 @@ public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 		LinkType result = new LinkType(d1, d2);
 		final String queue = getQueue(arg);
 		if (queue.contains(".")) {
-			result = result.getDashed();
+			result = result.goDashed();
 		} else if (queue.contains("~")) {
-			result = result.getDotted();
+			result = result.goDotted();
 		} else if (queue.contains("=")) {
-			result = result.getBold();
+			result = result.goBold();
 		}
 
 		final String middle = arg.get("INSIDE", 0);
@@ -207,6 +208,7 @@ public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 		private String firstLabel;
 		private String secondLabel;
 		private String labelLink;
+		private LinkArrow linkArrow = LinkArrow.NONE;
 
 		Labels(RegexResult arg) {
 			firstLabel = arg.get("LABEL1", 0);
@@ -218,6 +220,27 @@ public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 					init();
 				}
 				labelLink = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(labelLink);
+
+				if ("<".equals(labelLink)) {
+					linkArrow = LinkArrow.BACKWARD;
+					labelLink = null;
+				} else if (">".equals(labelLink)) {
+					linkArrow = LinkArrow.DIRECT_NORMAL;
+					labelLink = null;
+				} else if (labelLink != null && labelLink.startsWith("< ")) {
+					linkArrow = LinkArrow.BACKWARD;
+					labelLink = StringUtils.trin(labelLink.substring(2));
+				} else if (labelLink != null && labelLink.startsWith("> ")) {
+					linkArrow = LinkArrow.DIRECT_NORMAL;
+					labelLink = StringUtils.trin(labelLink.substring(2));
+				} else if (labelLink != null && labelLink.endsWith(" >")) {
+					linkArrow = LinkArrow.DIRECT_NORMAL;
+					labelLink = StringUtils.trin(labelLink.substring(0, labelLink.length() - 2));
+				} else if (labelLink != null && labelLink.endsWith(" <")) {
+					linkArrow = LinkArrow.BACKWARD;
+					labelLink = StringUtils.trin(labelLink.substring(0, labelLink.length() - 2));
+				}
+
 			}
 
 		}
@@ -287,18 +310,16 @@ public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 
 		Link link = new Link(cl1, cl2, linkType, Display.getWithNewlines(labels.labelLink), queue.length(),
 				labels.firstLabel, labels.secondLabel, diagram.getLabeldistance(), diagram.getLabelangle());
-
+		link.setLinkArrow(labels.linkArrow);
 		if (dir == Direction.LEFT || dir == Direction.UP) {
 			link = link.getInv();
 		}
-		Colors colors = color().getColor(arg, diagram.getSkinParam().getIHtmlColorSet());
-		colors = CommandLinkClass.applyStyle(arg.getLazzy("ARROW_STYLE", 0), link, colors);
+		link.setColors(color().getColor(arg, diagram.getSkinParam().getIHtmlColorSet()));
+		link.applyStyle(arg.getLazzy("ARROW_STYLE", 0));
 		if (arg.get("STEREOTYPE", 0) != null) {
 			final Stereotype stereotype = new Stereotype(arg.get("STEREOTYPE", 0));
-			colors = colors.applyStereotype(stereotype, diagram.getSkinParam(), ColorParam.arrow);
+			link.setColors(link.getColors().applyStereotype(stereotype, diagram.getSkinParam(), ColorParam.arrow));
 		}
-
-		link.setColors(colors);
 		diagram.addLink(link);
 		return CommandExecutionResult.ok();
 	}
@@ -342,7 +363,7 @@ public class CommandLinkElement extends SingleLineCommand2<DescriptionDiagram> {
 		if (dir == Direction.LEFT || dir == Direction.UP) {
 			link = link.getInv();
 		}
-		CommandLinkClass.applyStyle(arg.getLazzy("ARROW_STYLE", 0), link);
+		link.applyStyle(arg.getLazzy("ARROW_STYLE", 0));
 		diagram.addLink(link);
 		return CommandExecutionResult.ok();
 	}
