@@ -46,6 +46,7 @@ import java.awt.geom.Rectangle2D;
 import java.awt.image.BufferedImage;
 
 import net.sourceforge.plantuml.ColorParam;
+import net.sourceforge.plantuml.CornerParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineParam;
@@ -81,7 +82,7 @@ public class TextBlockUtils {
 		if (borderColor == null) {
 			borderColor = HtmlColorUtils.BLACK;
 		}
-		final double corner = skinParam.getRoundCorner("titleBorder", null);
+		final double corner = skinParam.getRoundCorner(CornerParam.titleBorder, null);
 		return withMargin(bordered(result, stroke, borderColor, backgroundColor, corner), 2, 2);
 	}
 
@@ -164,6 +165,10 @@ public class TextBlockUtils {
 			public Dimension2D calculateDimension(StringBounder stringBounder) {
 				return bloc.calculateDimension(stringBounder);
 			}
+			
+			public MinMax getMinMax(StringBounder stringBounder) {
+				return bloc.getMinMax(stringBounder);
+			}
 
 			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
 				if (strategy.check(display, member)) {
