@@ -35,12 +35,13 @@
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.AlignParam;
+import net.sourceforge.plantuml.AlignmentParam;
 import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineParam;
 import net.sourceforge.plantuml.PaddingParam;
+import net.sourceforge.plantuml.CornerParam;
 import net.sourceforge.plantuml.SkinParamUtils;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
@@ -99,37 +100,34 @@ public class Rose implements Skin {
 						config, param, param.maxMessageSize(), param.strictUmlStyle() == false);
 			}
 			final HorizontalAlignment messageHorizontalAlignment = param.getHorizontalAlignment(
-					AlignParam.SEQUENCE_MESSAGE_ALIGN, config.getArrowDirection());
+					AlignmentParam.sequenceMessageAlignment, config.getArrowDirection());
 			final HorizontalAlignment textHorizontalAlignment = param.getHorizontalAlignment(
-					AlignParam.SEQUENCE_MESSAGETEXT_ALIGN, config.getArrowDirection());
+					AlignmentParam.sequenceMessageTextAlignment, config.getArrowDirection());
 			return new ComponentRoseArrow(sequenceArrow, getUFont2(param, FontParam.ARROW), stringsToDisplay, config,
 					messageHorizontalAlignment, param, textHorizontalAlignment, param.maxMessageSize(),
-					param.strictUmlStyle() == false);
+					param.strictUmlStyle() == false, param.responseMessageBelowArrow());
 		}
 		final double padding = param.getPadding(PaddingParam.PARTICIPANT);
+		final double roundCorner = param.getRoundCorner(CornerParam.DEFAULT, null);
 		if (type == ComponentType.PARTICIPANT_HEAD) {
 			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.participantBorder), getUFont2(param,
-					FontParam.PARTICIPANT), stringsToDisplay, param, param.getRoundCorner("", null),
-					newFontForStereotype, getFontColor(param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(),
-					false, padding);
+					FontParam.PARTICIPANT), stringsToDisplay, param, roundCorner, newFontForStereotype, getFontColor(
+					param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(), false, padding);
 		}
 		if (type == ComponentType.PARTICIPANT_TAIL) {
 			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.participantBorder), getUFont2(param,
-					FontParam.PARTICIPANT), stringsToDisplay, param, param.getRoundCorner("", null),
-					newFontForStereotype, getFontColor(param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(),
-					false, padding);
+					FontParam.PARTICIPANT), stringsToDisplay, param, roundCorner, newFontForStereotype, getFontColor(
+					param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(), false, padding);
 		}
 		if (type == ComponentType.COLLECTIONS_HEAD) {
-			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.participantBorder), getUFont2(param,
-					FontParam.PARTICIPANT), stringsToDisplay, param, param.getRoundCorner("", null),
-					newFontForStereotype, getFontColor(param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(),
-					true, padding);
+			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.collectionsBorder), getUFont2(param,
+					FontParam.PARTICIPANT), stringsToDisplay, param, roundCorner, newFontForStereotype, getFontColor(
+					param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(), true, padding);
 		}
 		if (type == ComponentType.COLLECTIONS_TAIL) {
-			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.participantBorder), getUFont2(param,
-					FontParam.PARTICIPANT), stringsToDisplay, param, param.getRoundCorner("", null),
-					newFontForStereotype, getFontColor(param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(),
-					true, padding);
+			return new ComponentRoseParticipant(getSymbolContext(param, ColorParam.collectionsBorder), getUFont2(param,
+					FontParam.PARTICIPANT), stringsToDisplay, param, roundCorner, newFontForStereotype, getFontColor(
+					param, FontParam.SEQUENCE_STEREOTYPE), param.minClassWidth(), true, padding);
 		}
 		if (type == ComponentType.PARTICIPANT_LINE) {
 			final HtmlColor borderColor = getHtmlColor(param, ColorParam.sequenceLifeLineBorder);
@@ -151,57 +149,58 @@ public class Rose implements Skin {
 		}
 		if (type == ComponentType.BOUNDARY_HEAD) {
 			return new ComponentRoseBoundary(getSymbolContext(param, ColorParam.boundaryBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.BOUNDARY), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
+					FontParam.BOUNDARY_STEREOTYPE));
 		}
 		if (type == ComponentType.BOUNDARY_TAIL) {
 			return new ComponentRoseBoundary(getSymbolContext(param, ColorParam.boundaryBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.BOUNDARY), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
+					FontParam.BOUNDARY_STEREOTYPE));
 		}
 		if (type == ComponentType.CONTROL_HEAD) {
 			return new ComponentRoseControl(getSymbolContext(param, ColorParam.controlBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.CONTROL), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
+					FontParam.CONTROL_STEREOTYPE));
 		}
 		if (type == ComponentType.CONTROL_TAIL) {
 			return new ComponentRoseControl(getSymbolContext(param, ColorParam.controlBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.CONTROL), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
+					FontParam.CONTROL_STEREOTYPE));
 		}
 		if (type == ComponentType.ENTITY_HEAD) {
 			return new ComponentRoseEntity(getSymbolContext(param, ColorParam.entityBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.ENTITY), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
+					FontParam.ENTITY_STEREOTYPE));
 		}
 		if (type == ComponentType.ENTITY_TAIL) {
 			return new ComponentRoseEntity(getSymbolContext(param, ColorParam.entityBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.ENTITY), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
+					FontParam.ENTITY_STEREOTYPE));
 		}
 		if (type == ComponentType.QUEUE_HEAD) {
 			return new ComponentRoseQueue(getSymbolContext(param, ColorParam.entityBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.QUEUE), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
+					FontParam.QUEUE_STEREOTYPE));
 		}
 		if (type == ComponentType.QUEUE_TAIL) {
 			return new ComponentRoseQueue(getSymbolContext(param, ColorParam.entityBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.QUEUE), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
+					FontParam.QUEUE_STEREOTYPE));
 		}
 		if (type == ComponentType.DATABASE_HEAD) {
 			return new ComponentRoseDatabase(getSymbolContext(param, ColorParam.databaseBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.DATABASE), stringsToDisplay, true, param, newFontForStereotype, getFontColor(param,
+					FontParam.DATABASE_STEREOTYPE));
 		}
 		if (type == ComponentType.DATABASE_TAIL) {
 			return new ComponentRoseDatabase(getSymbolContext(param, ColorParam.databaseBorder), getUFont2(param,
-					FontParam.ACTOR), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
-					FontParam.SEQUENCE_STEREOTYPE));
+					FontParam.DATABASE), stringsToDisplay, false, param, newFontForStereotype, getFontColor(param,
+					FontParam.DATABASE_STEREOTYPE));
 		}
 		if (type == ComponentType.NOTE) {
+			final HorizontalAlignment alignment = param.getHorizontalAlignment(AlignmentParam.noteTextAlignment, null);
 			return new ComponentRoseNote(getSymbolContext(param, ColorParam.noteBorder), getUFont2(param,
-					FontParam.NOTE), stringsToDisplay, paddingX, paddingY, param);
+					FontParam.NOTE), stringsToDisplay, paddingX, paddingY, param, roundCorner, alignment);
 		}
 		if (type == ComponentType.NOTE_HEXAGONAL) {
 			return new ComponentRoseNoteHexagonal(getSymbolContext(param, ColorParam.noteBorder), getUFont2(param,
@@ -219,7 +218,7 @@ public class Rose implements Skin {
 				smallFont = smallFont.changeColor(smallColor);
 			}
 			return new ComponentRoseGroupingHeader(param.getBackgroundColor(), getSymbolContext(param,
-					ColorParam.sequenceGroupBorder), bigFont, smallFont, stringsToDisplay, param);
+					ColorParam.sequenceGroupBorder), bigFont, smallFont, stringsToDisplay, param, roundCorner);
 		}
 		if (type == ComponentType.GROUPING_ELSE) {
 			return new ComponentRoseGroupingElse(getHtmlColor(param, ColorParam.sequenceGroupBorder), getUFont2(param,
@@ -260,7 +259,7 @@ public class Rose implements Skin {
 		if (type == ComponentType.REFERENCE) {
 			return new ComponentRoseReference(getUFont2(param, FontParam.SEQUENCE_REFERENCE), getSymbolContext(param,
 					ColorParam.sequenceReferenceBorder), bigFont, stringsToDisplay, param.getHorizontalAlignment(
-					AlignParam.SEQUENCE_REFERENCE_ALIGN, null), param, getHtmlColor(param,
+					AlignmentParam.sequenceReferenceAlignment, null), param, getHtmlColor(param,
 					ColorParam.sequenceReferenceBackground));
 		}
 		// if (type == ComponentType.TITLE) {
@@ -273,7 +272,7 @@ public class Rose implements Skin {
 		// }
 		if (type == ComponentType.ENGLOBER) {
 			return new ComponentRoseEnglober(getSymbolContext(param, ColorParam.sequenceBoxBorder), stringsToDisplay,
-					getUFont2(param, FontParam.SEQUENCE_BOX), param);
+					getUFont2(param, FontParam.SEQUENCE_BOX), param, roundCorner);
 		}
 
 		return null;
@@ -304,6 +303,11 @@ public class Rose implements Skin {
 					ColorParam.controlBorder)).withStroke(getStroke(param, LineParam.sequenceActorBorder, 2))
 					.withDeltaShadow(deltaShadow(param));
 		}
+		if (color == ColorParam.collectionsBorder) {
+			return new SymbolContext(getHtmlColor(param, ColorParam.collectionsBackground), getHtmlColor(param,
+					ColorParam.collectionsBorder)).withStroke(getStroke(param, LineParam.sequenceActorBorder, 1.5))
+					.withDeltaShadow(deltaShadow(param));
+		}
 		if (color == ColorParam.entityBorder) {
 			return new SymbolContext(getHtmlColor(param, ColorParam.entityBackground), getHtmlColor(param,
 					ColorParam.entityBorder)).withStroke(getStroke(param, LineParam.sequenceActorBorder, 2))
