@@ -54,6 +54,7 @@ import net.sourceforge.plantuml.OptionFlags;
 import net.sourceforge.plantuml.Pragma;
 import net.sourceforge.plantuml.SkinParamForecolored;
 import net.sourceforge.plantuml.SkinParamSameClassWidth;
+import net.sourceforge.plantuml.SkinParamUtils;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
@@ -77,11 +78,14 @@ import net.sourceforge.plantuml.cucadiagram.dot.ExeState;
 import net.sourceforge.plantuml.cucadiagram.dot.GraphvizVersion;
 import net.sourceforge.plantuml.cucadiagram.dot.Neighborhood;
 import net.sourceforge.plantuml.cucadiagram.entity.EntityFactory;
+import net.sourceforge.plantuml.descdiagram.EntityImageDesignedDomain;
+import net.sourceforge.plantuml.descdiagram.EntityImageDomain;
+import net.sourceforge.plantuml.descdiagram.EntityImageMachine;
+import net.sourceforge.plantuml.descdiagram.EntityImageRequirement;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.GraphicStrings;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.HtmlColor;
-import net.sourceforge.plantuml.graphic.HtmlColorUtils;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockEmpty;
@@ -281,7 +285,8 @@ public final class DotDataImageBuilder {
 		final IEntityImage image = printEntityInternal(dotStringFactory, ent);
 		final Dimension2D dim = image.calculateDimension(stringBounder);
 		final Shape shape = new Shape(image, image.getShapeType(), dim.getWidth(), dim.getHeight(),
-				dotStringFactory.getColorSequence(), ent.isTop(), image.getShield(stringBounder), ent.getEntityPosition());
+				dotStringFactory.getColorSequence(), ent.isTop(), image.getShield(stringBounder),
+				ent.getEntityPosition());
 		dotStringFactory.addShape(shape);
 		dotStringFactory.getBibliotekon().putShape(ent, shape);
 	}
@@ -389,7 +394,7 @@ public final class DotDataImageBuilder {
 			}
 		}
 		if (leaf.getLeafType() == LeafType.USECASE) {
-			return new EntityImageUseCase(leaf, skinParam);
+			return new EntityImageUseCase(leaf, skinParam, portionShower);
 		}
 		// if (leaf.getEntityType() == LeafType.CIRCLE_INTERFACE) {
 		// return new EntityImageCircleInterface(leaf, skinParam);
@@ -411,8 +416,11 @@ public final class DotDataImageBuilder {
 		}
 		if (leaf.getLeafType() == LeafType.EMPTY_PACKAGE) {
 			if (leaf.getUSymbol() != null) {
-				return new EntityImageDescription(leaf, new SkinParamForecolored(skinParam, HtmlColorUtils.BLACK),
-						portionShower, links);
+				// final HtmlColor black = HtmlColorUtils.BLACK;
+				final HtmlColor black = SkinParamUtils.getColor(skinParam, leaf.getUSymbol().getColorParamBorder(),
+						leaf.getStereotype());
+				return new EntityImageDescription(leaf, new SkinParamForecolored(skinParam, black), portionShower,
+						links);
 			}
 			return new EntityImageEmptyPackage(leaf, skinParam, portionShower);
 		}
@@ -425,7 +433,28 @@ public final class DotDataImageBuilder {
 		if (leaf.getLeafType() == LeafType.TIPS) {
 			return new EntityImageTips(leaf, skinParam, bibliotekon);
 		}
-		throw new UnsupportedOperationException(leaf.getLeafType().toString());
+		// TODO Clean
+		if (leaf.getLeafType() == LeafType.DOMAIN && leaf.getStereotype() != null
+				&& leaf.getStereotype().isMachineOrSpecification()) {
+			return new EntityImageMachine(leaf, skinParam);
+		} else if (leaf.getLeafType() == LeafType.DOMAIN && leaf.getStereotype() != null
+				&& leaf.getStereotype().isDesignedOrSolved()) {
+			return new EntityImageDesignedDomain(leaf, skinParam);
+		} else if (leaf.getLeafType() == LeafType.REQUIREMENT) {
+			return new EntityImageRequirement(leaf, skinParam);
+		} else if (leaf.getLeafType() == LeafType.DOMAIN && leaf.getStereotype() != null
+				&& leaf.getStereotype().isLexicalOrGiven()) {
+			return new EntityImageDomain(leaf, skinParam, 'X');
+		} else if (leaf.getLeafType() == LeafType.DOMAIN && leaf.getStereotype() != null
+				&& leaf.getStereotype().isCausal()) {
+			return new EntityImageDomain(leaf, skinParam, 'C');
+		} else if (leaf.getLeafType() == LeafType.DOMAIN && leaf.getStereotype() != null
+				&& leaf.getStereotype().isBiddableOrUncertain()) {
+			return new EntityImageDomain(leaf, skinParam, 'B');
+		} else if (leaf.getLeafType() == LeafType.DOMAIN) {
+			return new EntityImageDomain(leaf, skinParam, 'P');
+		} else
+			throw new UnsupportedOperationException(leaf.getLeafType().toString());
 	}
 
 	private Collection<ILeaf> getUnpackagedEntities() {
