@@ -40,10 +40,12 @@ import java.awt.geom.Point2D;
 import java.util.Collection;
 import java.util.List;
 
+import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.Hideable;
 import net.sourceforge.plantuml.ISkinParam;
+import net.sourceforge.plantuml.LineParam;
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.Pragma;
 import net.sourceforge.plantuml.StringUtils;
@@ -64,6 +66,7 @@ import net.sourceforge.plantuml.graphic.AbstractTextBlock;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.HtmlColor;
+import net.sourceforge.plantuml.graphic.HtmlColorUtils;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockArrow;
@@ -77,7 +80,6 @@ import net.sourceforge.plantuml.posimo.DotPath;
 import net.sourceforge.plantuml.posimo.Moveable;
 import net.sourceforge.plantuml.posimo.Positionable;
 import net.sourceforge.plantuml.posimo.PositionableUtils;
-import net.sourceforge.plantuml.svek.SvekUtils.PointListIterator;
 import net.sourceforge.plantuml.svek.extremity.Extremity;
 import net.sourceforge.plantuml.svek.extremity.ExtremityFactory;
 import net.sourceforge.plantuml.svek.extremity.ExtremityFactoryExtends;
@@ -85,7 +87,6 @@ import net.sourceforge.plantuml.svek.image.EntityImageNoteLink;
 import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
 import net.sourceforge.plantuml.ugraphic.UChangeColor;
 import net.sourceforge.plantuml.ugraphic.UComment;
-import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
@@ -133,6 +134,8 @@ public class Line implements Moveable, Hideable {
 	private final Pragma pragma;
 	private final HtmlColor backgroundColor;
 	private final boolean useRankSame;
+	private final UStroke defaultThickness;
+	private HtmlColor arrowLollipopColor;
 
 	@Override
 	public String toString() {
@@ -232,6 +235,11 @@ public class Line implements Moveable, Hideable {
 			labelFont = labelFont.mute(link.getColors());
 		}
 		this.backgroundColor = skinParam.getBackgroundColor();
+		this.defaultThickness = skinParam.getThickness(LineParam.arrow, null);
+		this.arrowLollipopColor = skinParam.getHtmlColor(ColorParam.arrowLollipop, null, false);
+		if (arrowLollipopColor == null) {
+			this.arrowLollipopColor = HtmlColorUtils.WHITE;
+		}
 		this.pragma = pragma;
 		this.bibliotekon = bibliotekon;
 		this.stringBounder = stringBounder;
@@ -348,9 +356,9 @@ public class Line implements Moveable, Hideable {
 		sb.append(decoration);
 
 		int length = link.getLength();
-		// if (graphvizVersion == GraphvizVersion.V2_34_0 && length == 1) {
-		// length = 2;
-		// }
+		if (graphvizVersion.ignoreHorizontalLinks() && length == 1) {
+			length = 2;
+		}
 		if (useRankSame) {
 			if (pragma.horizontalLineBetweenDifferentPackageAllowed() || link.isInvis() || length != 1) {
 				// if (graphvizVersion.isJs() == false) {
@@ -365,7 +373,7 @@ public class Line implements Moveable, Hideable {
 		sb.append("color=\"" + StringUtils.getAsHtml(lineColor) + "\"");
 		if (labelText != null) {
 			sb.append(",");
-			if (graphvizVersion.modeSafe() || dotMode == DotMode.NO_LEFT_RIGHT_AND_XLABEL) {
+			if (graphvizVersion.useXLabelInsteadOfLabel() || dotMode == DotMode.NO_LEFT_RIGHT_AND_XLABEL) {
 				sb.append("xlabel=<");
 			} else {
 				sb.append("label=<");
@@ -507,27 +515,27 @@ public class Line implements Moveable, Hideable {
 
 	}
 
-	public void solveLine(final String svg, final int fullHeight, MinFinder corner1) {
+	public void solveLine(SvgResult fullSvg, MinFinder corner1) {
 		if (this.link.isInvis()) {
 			return;
 		}
 
-		int idx = SvekUtils.getIndexFromColor(svg, this.lineColor);
+		int idx = fullSvg.getIndexFromColor(this.lineColor);
 		if (idx == -1) {
 			return;
 			// throw new IllegalStateException();
 		}
-		idx = svg.indexOf("d=\"", idx);
+		idx = fullSvg.indexOf("d=\"", idx);
 		if (idx == -1) {
 			throw new IllegalStateException();
 		}
-		final int end = svg.indexOf("\"", idx + 3);
-		final String path = svg.substring(idx + 3, end);
+		final int end = fullSvg.indexOf("\"", idx + 3);
+		final SvgResult path = fullSvg.substring(idx + 3, end);
 
-		if (DotPath.isPathConsistent(path) == false) {
+		if (DotPath.isPathConsistent(path.getSvg()) == false) {
 			return;
 		}
-		dotPath = new DotPath(path, fullHeight);
+		dotPath = new DotPath(path);
 
 		if (projectionCluster != null) {
 			// System.err.println("Line::solveLine1 projectionCluster=" + projectionCluster.getClusterPosition());
@@ -540,7 +548,8 @@ public class Line implements Moveable, Hideable {
 		}
 		dotPath = dotPath.simulateCompound(lhead, ltail);
 
-		PointListIterator pointListIterator = PointListIterator.create(svg.substring(end), fullHeight, lineColor);
+		final SvgResult lineSvg = fullSvg.substring(end);
+		PointListIterator pointListIterator = lineSvg.getPointsWithThisColor(lineColor);
 
 		final LinkType linkType = link.getType();
 		this.extremity1 = getExtremity(linkType.getDecor2(), pointListIterator, dotPath.getStartPoint(),
@@ -557,7 +566,7 @@ public class Line implements Moveable, Hideable {
 				final double dist2start = p2.distance(dotPath.getStartPoint());
 				final double dist2end = p2.distance(dotPath.getEndPoint());
 				if (dist1start > dist1end && dist2end > dist2start) {
-					pointListIterator = PointListIterator.create(svg.substring(end), fullHeight, lineColor);
+					pointListIterator = lineSvg.getPointsWithThisColor(lineColor);
 					this.extremity2 = getExtremity(linkType.getDecor1(), pointListIterator, dotPath.getEndPoint(),
 							dotPath.getEndAngle(), lhead, bibliotekon.getShape(link.getEntity2()));
 					this.extremity1 = getExtremity(linkType.getDecor2(), pointListIterator, dotPath.getStartPoint(),
@@ -568,7 +577,7 @@ public class Line implements Moveable, Hideable {
 		}
 
 		if (this.labelText != null) {
-			final Point2D pos = getXY(svg, this.noteLabelColor, fullHeight);
+			final Point2D pos = getXY(fullSvg, this.noteLabelColor);
 			if (pos != null) {
 				corner1.manage(pos);
 				this.labelXY = TextBlockUtils.asPositionable(labelText, stringBounder, pos);
@@ -576,7 +585,7 @@ public class Line implements Moveable, Hideable {
 		}
 
 		if (this.startTailText != null) {
-			final Point2D pos = getXY(svg, this.startTailColor, fullHeight);
+			final Point2D pos = getXY(fullSvg, this.startTailColor);
 			if (pos != null) {
 				corner1.manage(pos);
 				this.startTailLabelXY = TextBlockUtils.asPositionable(startTailText, stringBounder, pos);
@@ -584,7 +593,7 @@ public class Line implements Moveable, Hideable {
 		}
 
 		if (this.endHeadText != null) {
-			final Point2D pos = getXY(svg, this.endHeadColor, fullHeight);
+			final Point2D pos = getXY(fullSvg, this.endHeadColor);
 			if (pos != null) {
 				corner1.manage(pos);
 				this.endHeadLabelXY = TextBlockUtils.asPositionable(endHeadText, stringBounder, pos);
@@ -601,12 +610,12 @@ public class Line implements Moveable, Hideable {
 		return dotPath.getBeziers().size() <= 1;
 	}
 
-	private Point2D.Double getXY(String svg, int color, int height) {
-		final int idx = SvekUtils.getIndexFromColor(svg, color);
+	private Point2D.Double getXY(SvgResult svgResult, int color) {
+		final int idx = svgResult.getIndexFromColor(color);
 		if (idx == -1) {
 			return null;
 		}
-		return SvekUtils.getMinXY(SvekUtils.extractPointsList(svg, idx, height));
+		return SvekUtils.getMinXY(svgResult.substring(idx).extractList(SvgResult.POINTS_EQUALS));
 
 	}
 
@@ -650,7 +659,7 @@ public class Line implements Moveable, Hideable {
 
 		ug = ug.apply(new UChangeBackColor(null)).apply(new UChangeColor(color));
 		final LinkType linkType = link.getType();
-		UStroke stroke = linkType.getStroke();
+		UStroke stroke = linkType.getStroke3(defaultThickness);
 		if (link.getColors() != null && link.getColors().getSpecificLineStroke() != null) {
 			stroke = link.getColors().getSpecificLineStroke();
 		}
@@ -716,7 +725,8 @@ public class Line implements Moveable, Hideable {
 			final PointAndAngle middle = dotPath.getMiddle();
 			final double angleRad = middle.getAngle();
 			final double angleDeg = -angleRad * 180.0 / Math.PI;
-			final UDrawable mi = linkType.getMiddleDecor().getMiddleFactory().createUDrawable(angleDeg - 45);
+			final UDrawable mi = linkType.getMiddleDecor().getMiddleFactory(arrowLollipopColor)
+					.createUDrawable(angleDeg - 45);
 			mi.drawU(ug.apply(new UTranslate(x + middle.getX(), y + middle.getY())));
 		}
 
