@@ -44,6 +44,7 @@ import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineConfigurable;
 import net.sourceforge.plantuml.LineParam;
+import net.sourceforge.plantuml.CornerParam;
 import net.sourceforge.plantuml.SkinParamUtils;
 import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.creole.Stencil;
@@ -84,7 +85,7 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 	public EntityImageClass(GraphvizVersion version, ILeaf entity, ISkinParam skinParam, PortionShower portionShower) {
 		super(entity, entity.getColors(skinParam).mute(skinParam));
 		this.lineConfig = entity;
-		this.roundCorner = getSkinParam().getRoundCorner("", null);
+		this.roundCorner = getSkinParam().getRoundCorner(CornerParam.DEFAULT, null);
 		this.shield = version != null && version.useShield() && entity.hasNearDecoration() ? Margins.uniform(16)
 				: Margins.NONE;
 		final boolean showMethods = portionShower.showPortion(EntityPortion.METHOD, entity);
@@ -139,7 +140,8 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 
 		final double widthTotal = dimTotal.getWidth();
 		final double heightTotal = dimTotal.getHeight();
-		final Shadowable rect = new URectangle(widthTotal, heightTotal, roundCorner, roundCorner, getEntity().getCode().getFullName());
+		final Shadowable rect = new URectangle(widthTotal, heightTotal, roundCorner, roundCorner, getEntity().getCode()
+				.getFullName());
 		if (getSkinParam().shadowing()) {
 			rect.setDeltaShadow(4);
 		}
@@ -162,11 +164,13 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 		if (headerBackcolor == null) {
 			headerBackcolor = getSkinParam().getHtmlColor(ColorParam.classHeaderBackground, getStereo(), false);
 		}
+		UGraphic ugHeader = ug;
 		if (headerBackcolor != null) {
 			final Shadowable rect2 = new URectangle(widthTotal, dimHeader.getHeight());
-			ug.apply(new UChangeBackColor(headerBackcolor)).apply(stroke).draw(rect2);
+			ugHeader = ugHeader.apply(new UChangeBackColor(headerBackcolor));
+			ugHeader.apply(stroke).draw(rect2);
 		}
-		header.drawU(ug, dimTotal.getWidth(), dimHeader.getHeight());
+		header.drawU(ugHeader, dimTotal.getWidth(), dimHeader.getHeight());
 
 		if (body != null) {
 			final UGraphic ug2 = UGraphicStencil.create(ug, this, stroke);
