@@ -35,6 +35,7 @@
 package net.sourceforge.plantuml.timingdiagram;
 
 import java.awt.geom.Dimension2D;
+import java.awt.geom.Rectangle2D;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.ArrayList;
@@ -42,15 +43,25 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
+import net.sourceforge.plantuml.AnnotatedWorker;
+import net.sourceforge.plantuml.ColorParam;
+import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.FileFormatOption;
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.UmlDiagram;
 import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
+import net.sourceforge.plantuml.graphic.HtmlColor;
+import net.sourceforge.plantuml.graphic.HtmlColorSet;
 import net.sourceforge.plantuml.graphic.HtmlColorUtils;
+import net.sourceforge.plantuml.graphic.InnerStrategy;
 import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.UDrawable;
+import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 import net.sourceforge.plantuml.ugraphic.ImageBuilder;
+import net.sourceforge.plantuml.ugraphic.MinMax;
 import net.sourceforge.plantuml.ugraphic.UChangeColor;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
@@ -82,16 +93,40 @@ public class TimingDiagram extends UmlDiagram implements Clock {
 		final ImageBuilder imageBuilder = new ImageBuilder(getSkinParam(), dpiFactor,
 				fileFormatOption.isWithMetadata() ? getMetadata() : null, getWarningOrError(), margin, margin,
 				getAnimation());
-		imageBuilder.setUDrawable(getUDrawable());
+
+		TextBlock result = getTextBlock();
+		final ISkinParam skinParam = getSkinParam();
+		result = new AnnotatedWorker(this, skinParam).addAdd(result);
+		imageBuilder.setUDrawable(result);
 
 		return imageBuilder.writeImageTOBEMOVED(fileFormatOption, seed(), os);
 	}
 
-	private UDrawable getUDrawable() {
-		return new UDrawable() {
+	private TextBlockBackcolored getTextBlock() {
+		return new TextBlockBackcolored() {
+
 			public void drawU(UGraphic ug) {
 				drawInternal(ug);
 			}
+
+			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+				return null;
+			}
+
+			public Dimension2D calculateDimension(StringBounder stringBounder) {
+				final UTranslate lastTranslate = getUTranslateForPlayer(null, stringBounder);
+				final double withBeforeRuler = getWithBeforeRuler(stringBounder);
+				final double totalWith = withBeforeRuler + ruler.getWidth() + marginX1 + marginX2;
+				return new Dimension2DDouble(totalWith, lastTranslate.getDy() + ruler.getHeight(stringBounder));
+			}
+
+			public MinMax getMinMax(StringBounder stringBounder) {
+				throw new UnsupportedOperationException();
+			}
+
+			public HtmlColor getBackcolor() {
+				return null;
+			}
 		};
 	}
 
@@ -151,7 +186,7 @@ public class TimingDiagram extends UmlDiagram implements Clock {
 		}
 
 		final TimeArrow timeArrow = TimeArrow.create(pt1.translated(translate1), pt2.translated(translate2),
-				message.getLabel(), getSkinParam());
+				message.getLabel(), getSkinParam(), message);
 		timeArrow.drawU(ug);
 
 	}
@@ -177,10 +212,11 @@ public class TimingDiagram extends UmlDiagram implements Clock {
 		lastPlayer = player;
 	}
 
-	public void createTimeMessage(Player player1, TimeTick time1, Player player2, TimeTick time2, String label) {
+	public TimeMessage createTimeMessage(Player player1, TimeTick time1, Player player2, TimeTick time2, String label) {
 		final TimeMessage message = new TimeMessage(new TickInPlayer(player1, time1), new TickInPlayer(player2, time2),
 				label);
 		messages.add(message);
+		return message;
 	}
 
 	public void addTime(TimeTick time) {
